@@ -21,8 +21,8 @@ from noc.lib.svg import vertical_text_svg
 from noc.main.report import report_registry
 from noc.main.menu import MENU
 from noc.main.search import search as search_engine
-from noc.main.models import RefBook, RefBookData
-import os, types, ConfigParser, sets, pwd, re
+from noc.main.models import RefBook, RefBookData, TimePattern
+import os, types, ConfigParser, pwd, re, time, datetime
 
 ##
 ## Startup boilerplate
@@ -136,7 +136,7 @@ def search(request):
 ##
 ## Configuration editor
 ##
-CONFIGS=["noc.conf","noc-launcher.conf","noc-fcgi.conf","noc-sae.conf","noc-activator.conf","noc-classifier.conf","noc-correlator.conf"]
+CONFIGS=["noc.conf","noc-launcher.conf","noc-fcgi.conf","noc-sae.conf","noc-activator.conf","noc-classifier.conf","noc-correlator.conf","noc-notifier.conf"]
 
 def config_index(request):
     config_list=CONFIGS[:]
@@ -187,11 +187,11 @@ def config_view(request,config):
     system_user=pwd.getpwuid(os.getuid())[0]
     defaults_conf=ConfigParser.RawConfigParser()
     defaults_conf.read("etc/%s.defaults"%config[:-5])
-    sections=sets.Set(conf.sections())
+    sections=set(conf.sections())
     sections.update(defaults_conf.sections())
     data=[]
     for s in sections:
-        options=sets.Set()
+        options=set()
         if conf.has_section(s):
             options.update(conf.options(s))
         if defaults_conf.has_section(s):
@@ -243,21 +243,6 @@ def refbook_index(request):
 def refbook_view(request,refbook_id):
     rb=get_object_or_404(RefBook,id=int(refbook_id))
     can_edit=not rb.is_builtin and request.user.has_perm("main.change_refbookdata")
-    if request.POST: # Edit refbook
-        if not can_edit:
-            return HttpResponseForbidden("Read-only refbook")
-        # Retrieve record data
-        fns=[int(k[6:]) for k in request.POST.keys() if k.startswith("field_")]
-        data=["" for i in range(max(fns)+1)]
-        for i in fns:
-            data[i]=request.POST["field_%d"%i]
-        record_id=int(request.POST["record_id"])
-        if record_id: # Edit existing
-            record=get_object_or_404(RefBookData,id=int(request.POST["record_id"]))
-            record.value=data
-        else: # Create new
-            record=RefBookData(ref_book=rb,value=data)
-        record.save()
     queryset=rb.refbookdata_set.all()
     # Search
     if request.GET and request.GET.has_key("query") and request.GET["query"]:
@@ -284,6 +269,56 @@ def refbook_view(request,refbook_id):
         paginate_by=100,
     )
 ##
+##
+##
+def refbook_item(request,refbook_id,record_id):
+    rb=get_object_or_404(RefBook,id=int(refbook_id))
+    rbr=get_object_or_404(RefBookData,id=int(record_id),ref_book=rb)
+    can_edit=not rb.is_builtin and request.user.has_perm("main.change_refbookdata")
+    return render(request,"main/refbook_item.html",{"rb":rb,"record":rbr,"can_edit":can_edit})
+##
+##
+##
+def refbook_edit(request,refbook_id,record_id=0):
+    rb=get_object_or_404(RefBook,id=int(refbook_id))
+    rbr=get_object_or_404(RefBookData,id=int(record_id),ref_book=rb)
+    can_edit=not rb.is_builtin and request.user.has_perm("main.change_refbookdata")
+    if not can_edit:
+        return HttpResponseForbidden("Read-only refbook")
+    if request.POST: # Edit refbook
+        if not can_edit:
+            return HttpResponseForbidden("Read-only refbook")
+        # Retrieve record data
+        fns=[int(k[6:]) for k in request.POST.keys() if k.startswith("field_")]
+        data=["" for i in range(max(fns)+1)]
+        for i in fns:
+            data[i]=request.POST["field_%d"%i]
+        rbr.value=data
+        rbr.save()
+        return HttpResponseRedirect("/main/refbook/%d/%d/"%(rb.id,rbr.id))
+    return render(request,"main/refbook_edit.html",{"rb":rb,"record":rbr})
+##
+##
+##
+def refbook_new(request,refbook_id):
+    rb=get_object_or_404(RefBook,id=int(refbook_id))
+    can_edit=not rb.is_builtin and request.user.has_perm("main.change_refbookdata")
+    if not can_edit:
+        return HttpResponseForbidden("Read-only refbook")
+    if request.POST: # Edit refbook
+        if not can_edit:
+            return HttpResponseForbidden("Read-only refbook")
+        # Retrieve record data
+        fns=[int(k[6:]) for k in request.POST.keys() if k.startswith("field_")]
+        data=["" for i in range(max(fns)+1)]
+        for i in fns:
+            data[i]=request.POST["field_%d"%i]
+        rbr=RefBookData(ref_book=rb,value=data)
+        rbr.save()
+        return HttpResponseRedirect("/main/refbook/%d/%d/"%(rb.id,rbr.id))
+    return render(request,"main/refbook_new.html",{"rb":rb})
+
+##
 ## Delete refbook record
 ##
 def refbook_delete(request,refbook_id,record_id):
@@ -303,3 +338,21 @@ def svg_text_vertical(request):
     else:
         text=u""
     return HttpResponse(vertical_text_svg(text),mimetype="image/svg+xml")
+##
+## Test Time Pattern
+##
+class TimePatternTestForm(forms.Form):
+    time=forms.DateTimeField(input_formats=["%d.%m.%Y %H:%M:%S"])
+    
+def time_pattern_test(request,time_pattern_id):
+    time_pattern=get_object_or_404(TimePattern,id=int(time_pattern_id))
+    result=None
+    if request.POST:
+        form=TimePatternTestForm(request.POST)
+        if form.is_valid():
+            result=time_pattern.match(form.cleaned_data["time"])
+    else:
+        now=datetime.datetime.now()
+        s="%02d.%02d.%04d %02d:%02d:%02d"%(now.day,now.month,now.year,now.hour,now.minute,now.second)
+        form=TimePatternTestForm(initial={"time":s})
+    return render(request,"main/time_pattern_test.html",{"time_pattern":time_pattern,"form":form,"result":result})
