@@ -7,7 +7,7 @@
 ##----------------------------------------------------------------------
 """
 """
-import os,logging,pty,signal,time,re,sys,signal,Queue,sets,cPickle,tempfile
+import os,logging,pty,signal,time,re,sys,signal,Queue,cPickle,tempfile
 from errno import ECONNREFUSED
 from noc.sa.profiles import profile_registry
 from noc.sa.script import script_registry,ScriptSocket
@@ -16,7 +16,7 @@ from noc.sa.protocols.sae_pb2 import *
 from noc.lib.fileutils import safe_rewrite
 from noc.lib.daemon import Daemon
 from noc.lib.fsm import FSM,check_state
-from noc.lib.nbsocket import ConnectedTCPSocket,SocketFactory,PTYSocket
+from noc.lib.nbsocket import ConnectedTCPSocket,ConnectedTCPSSLSocket,SocketFactory,PTYSocket,HAS_SSL
 from noc.lib.debug import DEBUG_CTX_CRASH_PREFIX
 from threading import Lock
 
@@ -84,7 +84,7 @@ class Service(SAEService):
     
     def ping_check(self,controller,request,done):
         def ping_check_callback(unreachable):
-            u=sets.Set(unreachable)
+            u=set(unreachable)
             r=PingCheckResponse()
             self.activator.ping_check_results={} # Reset previous ping checks
             for a in request.addresses:
@@ -117,6 +117,25 @@ class ActivatorSocket(RPCSocket,ConnectedTCPSocket):
     def on_conn_refused(self):
         self.activator_event("refused")
 ##
+## SSL-enabled Activator socket
+##
+class ActivatorSSLSocket(RPCSocket,ConnectedTCPSSLSocket):
+    def __init__(self,factory,address,port,local_address=None):
+        ConnectedTCPSSLSocket.__init__(self,factory,address,port,local_address)
+        RPCSocket.__init__(self,factory.activator.service)
+        
+    def activator_event(self,event):
+        self.factory.activator.event(event)
+
+    def on_connect(self):
+        self.activator_event("connect")
+
+    def on_close(self):
+        self.activator_event("close")
+
+    def on_conn_refused(self):
+        self.activator_event("refused")
+##
 ## External fping process.
 ## Runs fping, supplies a list of checked hosts
 ## and reads a list uf unreachable hosts
@@ -199,7 +218,7 @@ class Activator(Daemon,FSM):
         self.children={}
         self.ping_check_results={} # address -> last ping check result
         self.sae_stream=None
-        self.event_sources=sets.Set()
+        self.event_sources=set()
         self.trap_collectors=[]   # List of SNMP Trap collectors
         self.syslog_collectors=[] # List of SYSLOG collectors
         logging.info("Loading profile classes")
@@ -230,8 +249,12 @@ class Activator(Daemon,FSM):
     ##
     def on_CONNECT_enter(self):
         self.set_timeout(10)
-        self.sae_stream=ActivatorSocket(self.factory,self.config.get("sae","host"),self.config.getint("sae","port"),
-            self.config.get("sae","local_address"))
+        if HAS_SSL and self.config.get("sae","ssl_host"):
+            self.sae_stream=ActivatorSSLSocket(self.factory,self.config.get("sae","ssl_host"),self.config.getint("sae","ssl_port"),
+                self.config.get("sae","local_address"))
+        else:
+            self.sae_stream=ActivatorSocket(self.factory,self.config.get("sae","host"),self.config.getint("sae","port"),
+                self.config.get("sae","local_address"))
     ##
     ## CONNECTED state
     ##
@@ -487,7 +510,7 @@ class Activator(Daemon,FSM):
             if error:
                 logging.error("get_event_filter error: %s"%error.text)
                 return
-            self.event_sources=sets.Set(response.sources)
+            self.event_sources=set(response.sources)
             self.next_filter_update=time.time()+response.expire
         r=EventFilterRequest()
         self.sae_stream.proxy.event_filter(r,event_filter_callback)
