@@ -9,7 +9,7 @@
 """
 """
 from django.contrib import admin
-from noc.vc.models import VCDomain,VC
+from noc.vc.models import VCDomain,VC,VCType
 
 ##
 ## Admin form for VCDomain
@@ -22,6 +22,10 @@ class VCAdmin(admin.ModelAdmin):
     list_display=["vc_domain","type","l1","l2","description"]
     search_fields=["l1","l2","description"]
     list_filter=["vc_domain","type"]
+##
+class VCTypeAdmin(admin.ModelAdmin):
+    list_display=["name","min_labels","label1_min","label1_max","label2_min","label2_max"]
 
 admin.site.register(VCDomain,VCDomainAdmin)
-admin.site.register(VC,VCAdmin)
\ No newline at end of file
+admin.site.register(VCType,VCTypeAdmin)
+admin.site.register(VC,VCAdmin)
